import { Transactionable } from '@nocobase/database';
import { Plugin } from '@nocobase/server';
import { Registry } from '@nocobase/utils';
import { Logger } from '@nocobase/logger';
import Processor from './Processor';
import { CustomFunction } from './functions';
import Trigger from './triggers';
import { InstructionInterface } from './instructions';
import type { ExecutionModel, WorkflowModel } from './types';
type ID = number | string;
export default class PluginWorkflowServer extends Plugin {
    instructions: Registry<InstructionInterface>;
    triggers: Registry<Trigger>;
    functions: Registry<CustomFunction>;
    enabledCache: Map<number, WorkflowModel>;
    private ready;
    private executing;
    private pending;
    private events;
    private eventsCount;
    private loggerCache;
    private meter;
    private onBeforeSave;
    /**
     * @experimental
     */
    getLogger(workflowId: ID): Logger;
    /**
     * @experimental
     * @param {WorkflowModel} workflow
     * @returns {boolean}
     */
    isWorkflowSync(workflow: WorkflowModel): boolean;
    registerTrigger<T extends Trigger>(type: string, trigger: T | {
        new (p: Plugin): T;
    }): void;
    registerInstruction(type: string, instruction: InstructionInterface | {
        new (p: Plugin): InstructionInterface;
    }): void;
    private initTriggers;
    private initInstructions;
    /**
     * @internal
     */
    load(): Promise<void>;
    private toggle;
    trigger(workflow: WorkflowModel, context: object, options?: {
        [key: string]: any;
    } & Transactionable): void | Promise<Processor | null>;
    private triggerSync;
    resume(job: any): Promise<void>;
    createProcessor(execution: ExecutionModel, options?: {}): Processor;
    private createExecution;
    private prepare;
    private dispatch;
    private process;
    /**
     * @experimental
     * @param {string} dataSourceName
     * @param {Transaction} transaction
     * @param {boolean} create
     * @returns {Trasaction}
     */
    useDataSourceTransaction(dataSourceName: string, transaction: any, create?: boolean): any;
}
export {};
